@@ -912,8 +912,8 @@ below/after the form element.|,
     },
 
     'viewScreenTitle' => {
-        message => q|The title for the view screen|,
-        lastUpdated => 1104630516,
+        message => q|The title for the view screen.  This is the concatenation of all values for fields which have View Screen Title set for this Thing.  If no fields are set, then the title is empty.|,
+        lastUpdated => 1298915023,
     },
 
     'import_url' => {
@@ -923,8 +923,7 @@ below/after the form element.|,
     },
 
     'export_url' => {
-        message => q|Url to export the data in a search result into a csv file. This is only available after a
-search has been done.|,
+        message => q|Url to export the all data in a thing into a csv file.|,
         lastUpdated => 1104630516,
         context => q|Description of a tmpl_var for the template help.|,
     },
